# COPR Ligenix's spec file for glpi-plugin-glpiinventory
#
# Copyright (c) 2022-2025 Jean-Marc Liger
#
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global pluginname glpiinventory
%global glpi_min   10.0.10
%global glpi_max   10.1.0

Name:           glpi-plugin-%{pluginname}
Version:        1.5.3
Release:        1%{?dist}
Summary:        Plugin to handle various types of tasks for GLPI agents

License:        AGPLv3+
URL:            https://github.com/glpi-project/glpi-inventory-plugin

Source0:        https://github.com/glpi-project/glpi-inventory-plugin/releases/download/%{version}/glpi-%{pluginname}-%{version}.tar.bz2

BuildArch:      noarch

%if 0%{?fedora} || 0%{?rhel} >= 8
Requires:      (glpi >= %{glpi_min} with glpi < %{glpi_max})
%else
Requires:       glpi >= %{glpi_min}
Requires:       glpi <  %{glpi_max}
%endif

Obsoletes:  glpi-plugin-fusioninventory <= 10.0.12+1.0
Provides:   glpi-plugin-fusioninventory


%description
Plugin to handle various types of tasks for GLPI agents:
- Network discovery and inventory (SNMP)
- Software deployment
- VMWare ESX host remote inventory
- Collect data (files, Windows registry, WMI)

Computer and Network inventories themselves are done on GLPI side; the plugin only handle network related tasks.


%prep
%setup -q -c

grep "define('PLUGIN_GLPI_INVENTORY_GLPI_M.._VERSION" %{pluginname}/setup.php

# remove unused files
rm %{pluginname}/{.,}*.xml
rm %{pluginname}/phpstan.neon
rm %{pluginname}/composer.json

# move doc files
mkdir docs
mv %{pluginname}/*.md docs/

# .htaccess replaced by a httpd config file
rm %{pluginname}/install/mysql/.htaccess

# protect install files
cat >httpd <<EOF
<Directory /usr/share/glpi/plugins/%{pluginname}/install/mysql>
    <IfModule mod_authz_core.c>
        Require all denied
    </IfModule>
    <IfModule !mod_authz_core.c>
        Order Allow,Deny
        Deny from all
    </IfModule>
</Directory>

<Directory /usr/share/glpi/plugins/%{pluginname}>
    <IfModule mod_php5.c>
        php_admin_flag allow_url_fopen On
    </IfModule>
    <IfModule mod_php7.c>
        php_admin_flag allow_url_fopen On
    </IfModule>
</Directory>
EOF

# override PHP configuration for php-fpm
cat >php <<EOF
allow_url_fopen=On
EOF

# Create link to LICENSE for standard doc folder
ln -s %{_datadir}/glpi/plugins/%{pluginname}/LICENSE LICENSE


%build
# empty build


%install
mkdir -p %{buildroot}%{_localstatedir}/lib/glpi/files/_plugins/%{pluginname}

mkdir -p %{buildroot}/%{_datadir}/glpi/plugins
cp -ar %{pluginname} %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}

# apache
install -p -D -m 644 httpd %{buildroot}%{_sysconfdir}/httpd/conf.d/%{name}.conf

# php
install -p -D -m 644 php %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}/.user.ini

for i in %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}/locales/*
do
  lang=$(basename $i)
  echo "%lang(${lang:0:2}) %{_datadir}/glpi/plugins/%{pluginname}/locales/${lang}"
done | tee %{name}.lang


%files -f %{name}.lang
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc docs/*
%config(noreplace) %{_sysconfdir}/httpd/conf.d/%{name}.conf
%dir %{_datadir}/glpi/plugins/%{pluginname}
%dir %{_datadir}/glpi/plugins/%{pluginname}/locales
# LICENSE file required by installation process
%{_datadir}/glpi/plugins/%{pluginname}/LICENSE
%{_datadir}/glpi/plugins/%{pluginname}/*.php
%{_datadir}/glpi/plugins/%{pluginname}/ajax
%{_datadir}/glpi/plugins/%{pluginname}/b
%{_datadir}/glpi/plugins/%{pluginname}/css
%{_datadir}/glpi/plugins/%{pluginname}/front
%{_datadir}/glpi/plugins/%{pluginname}/inc
%{_datadir}/glpi/plugins/%{pluginname}/install
%{_datadir}/glpi/plugins/%{pluginname}/js
%{_datadir}/glpi/plugins/%{pluginname}/lib
%{_datadir}/glpi/plugins/%{pluginname}/pics
%{_datadir}/glpi/plugins/%{pluginname}/report
%{_datadir}/glpi/plugins/%{pluginname}/templates
%{_datadir}/glpi/plugins/%{pluginname}/vendor
%{_datadir}/glpi/plugins/%{pluginname}/.user.ini
# data
%attr(750,apache,root) %{_localstatedir}/lib/glpi/files/_plugins/%{pluginname}


%changelog
* Sun May 18 2025 Jean-Marc Liger <ligenix@iscp.fr> - 1.5.3-1
- Update to 1.5.3

* Fri May 02 2025 Jean-Marc Liger <ligenix@iscp.fr> - 1.5.2-1
- Update to 1.5.2

* Tue Mar 25 2025 Jean-Marc Liger <ligenix@iscp.fr> - 1.5.0-1
- Update to 1.5.0

* Fri Nov 08 2024 Jean-Marc Liger <ligenix@iscp.fr> - 1.4.0-2
- Obsoletes discontinued glpi-plugin-fusioninventory

* Tue Sep 17 2024 Jean-Marc Liger <ligenix@iscp.fr> - 1.4.0-1
- Update to 1.4.0

* Mon Mar 18 2024 Jean-Marc Liger <ligenix@iscp.fr> - 1.3.5-1
- Update to 1.3.5

* Sun Dec 17 2023 Jean-Marc Liger <ligenix@iscp.fr> - 1.3.4-1
- Update to 1.3.4

* Thu Nov 09 2023 Jean-Marc Liger <ligenix@iscp.fr> - 1.3.3-1
- Update to 1.3.3

* Fri Oct 20 2023 Jean-Marc Liger <ligenix@iscp.fr> - 1.3.1-1
- Update to 1.3.1

* Thu Oct 12 2023 Jean-Marc Liger <ligenix@iscp.fr> - 1.3.0-1
- Update to 1.3.0

* Tue Jul 11 2023 Jean-Marc Liger <ligenix@iscp.fr> - 1.2.3-1
- Update to 1.2.3

* Fri Jul 07 2023 Jean-Marc Liger <ligenix@iscp.fr> - 1.2.2-1
- Update to 1.2.2

* Mon May 01 2023 Jean-Marc Liger <ligenix@iscp.fr> - 1.2.1-2
- Add apache and php conf files

* Mon May 01 2023 Jean-Marc Liger <ligenix@iscp.fr> - 1.2.1-1
- Update to 1.2.1

* Mon Dec 12 2022 Jean-Marc Liger <ligenix@iscp.fr> - 1.0.6-1
- Update to 1.0.6

* Mon Nov 14 2022 Jean-Marc Liger <ligenix@iscp.fr> - 1.0.5-1
- Update to 1.0.5
- Correct License

* Thu Sep 15 2022 Jean-Marc Liger <ligenix@iscp.fr> - 1.0.4-1
- Update to 1.0.4

* Sat Jul 30 2022 Jean-Marc Liger <ligenix@iscp.fr> - 1.0.3-2
- Correct URL

* Sat Jul 30 2022 Jean-Marc Liger <ligenix@iscp.fr> - 1.0.3-1
- Version 1.0.3 for GLPI 10.0.x
- Initial RPM based on Remi Collet previous GLPI plugins spec files
